# inbox — features


本 domain 下的所有功能：

- ✅ [FEAT-017 inbox-list](./FEAT-017-inbox-list.md) — done
- ✅ [FEAT-018 inbox-show](./FEAT-018-inbox-show.md) — done
- ✅ [FEAT-019 inbox-reply](./FEAT-019-inbox-reply.md) — done
- ✅ [FEAT-020 inbox-delete](./FEAT-020-inbox-delete.md) — done
- ✅ [FEAT-021 inbox-report](./FEAT-021-inbox-report.md) — done
